==> pyside6-6.4.0.1-1-aarch64.pkg.tar.xz: usr/include/PySide6/QtSvgWidgets/pyside6_qtsvgwidgets_python.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only


#ifndef SBK_QTSVGWIDGETS_PYTHON_H
#define SBK_QTSVGWIDGETS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtsvg_python.h>
#include <pyside6_qtgui_python.h>
#include <pyside6_qtcore_python.h>
#include <pyside6_qtwidgets_python.h>

// Bound library includes
#include <QtSvgWidgets/qgraphicssvgitem.h>
#include <QtSvgWidgets/qsvgwidget.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <QString>
#include <QStringList>
#include <QStringView>

// Conversion Includes - Container Types
#include <pysideqflags.h>
#include <QList>
#include <QMap>
#include <pysideqflags.h>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>

// Type indices
enum : int {
    SBK_QGRAPHICSSVGITEM_IDX                                 = 0,
    SBK_QSVGWIDGET_IDX                                       = 1,
    SBK_QtSvgWidgets_IDX_COUNT                               = 2
};
// This variable stores all Python types exported by this module.
extern PyTypeObject **SbkPySide6_QtSvgWidgetsTypes;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkPySide6_QtSvgWidgetsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkPySide6_QtSvgWidgetsTypeConverters;

// Converter indices
enum : int {
    SBK_QTSVGWIDGETS_QLIST_INT_IDX                           = 0, // QList<int >
    SBK_QTSVGWIDGETS_QLIST_QACTIONPTR_IDX                    = 1, // QList<QAction* >
    SBK_QTSVGWIDGETS_QLIST_QVARIANT_IDX                      = 2, // QList<QVariant >
    SBK_QTSVGWIDGETS_QLIST_QSTRING_IDX                       = 3, // QList<QString >
    SBK_QTSVGWIDGETS_QMAP_QSTRING_QVARIANT_IDX               = 4, // QMap<QString,QVariant >
    SBK_QtSvgWidgets_CONVERTERS_IDX_COUNT                    = 5
};
// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
template<> inline PyTypeObject *SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSvgWidgetsTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
template<> inline PyTypeObject *SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSvgWidgetsTypes[SBK_QSVGWIDGET_IDX]); }
QT_WARNING_POP

} // namespace Shiboken

#endif // SBK_QTSVGWIDGETS_PYTHON_H

==> pyside6-6.4.1-2-aarch64.pkg.tar.xz: usr/include/PySide6/QtSvgWidgets/pyside6_qtsvgwidgets_python.h <==
// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only


#ifndef SBK_QTSVGWIDGETS_PYTHON_H
#define SBK_QTSVGWIDGETS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtsvg_python.h>
#include <pyside6_qtgui_python.h>
#include <pyside6_qtcore_python.h>
#include <pyside6_qtwidgets_python.h>

// Bound library includes
class QGraphicsSvgItem;
class QSvgWidget;
// Type indices
enum : int {
    SBK_QGRAPHICSSVGITEM_IDX                                 = 0,
    SBK_QSVGWIDGET_IDX                                       = 1,
    SBK_QtSvgWidgets_IDX_COUNT                               = 2
};
// This variable stores all Python types exported by this module.
extern PyTypeObject **SbkPySide6_QtSvgWidgetsTypes;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkPySide6_QtSvgWidgetsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkPySide6_QtSvgWidgetsTypeConverters;

// Converter indices
enum : int {
    SBK_QTSVGWIDGETS_QLIST_INT_IDX                           = 0, // QList<int >
    SBK_QTSVGWIDGETS_QLIST_QACTIONPTR_IDX                    = 1, // QList<QAction* >
    SBK_QTSVGWIDGETS_QLIST_QVARIANT_IDX                      = 2, // QList<QVariant >
    SBK_QTSVGWIDGETS_QLIST_QSTRING_IDX                       = 3, // QList<QString >
    SBK_QTSVGWIDGETS_QMAP_QSTRING_QVARIANT_IDX               = 4, // QMap<QString,QVariant >
    SBK_QtSvgWidgets_CONVERTERS_IDX_COUNT                    = 5
};
// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
template<> inline PyTypeObject *SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSvgWidgetsTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
template<> inline PyTypeObject *SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtSvgWidgetsTypes[SBK_QSVGWIDGET_IDX]); }
QT_WARNING_POP

} // namespace Shiboken

#endif // SBK_QTSVGWIDGETS_PYTHON_H
